@@ -24,6 +24,7 @@ def ReadChipID(device) :
     if isOK != True :
         print("FAIL: ReadReg,  Check the connection between TMonitor and T4/T5 Device")
         quit()
+    #regValueList = device.DD_DSIM_MipiReadReg(0, regAddr, byteOffset, readCount)
 
     # ChipID 읽은 결과 출력
     for regValue in regValueList :
@@ -39,8 +40,8 @@ if __name__ == "__main__" :
     print("----------------------------------------------")
 
     #TDevice 객체 생성, T5연결하는 Device객체이다.
-    #device = TDevice(TDevice.Type.T5)
-    device = TDevice(TDevice.Type.TESys)
+    device = TDevice(TDevice.Type.T5)
+    #device = TDevice(TDevice.Type.TESys)
 
     ReadChipID(device)
 
