@@ -155,15 +155,16 @@ class TDeviceBase(metaclass=ABCMeta) :
         voltList=this.RegAdcGetAllVoltage()
         for chIdx in range(this.__RegAdcMaxChCount) :
             print("RegAdc-VoltAll(%d) : %d "%(chIdx, voltList[chIdx]))
-    
+        
     @abstractmethod            
     def SysSetServerIPAddr(this, serverIPAddr) : pass
 
     @abstractmethod            
     def SysSetBoardID(this, boardID) : pass
 
+    #TDEVICE_API TED_BOOL TDeviceSysSetBoardID(void* hdl, int boardID);
     @abstractmethod            
-    def SetTcLocalSave(this, boardID, bFlag) : pass
+    def SysSetTcLocalSave(this, boardID, bFlag) : pass
         
     @abstractmethod            
     def SysGetDutIndexAllDeviceValue(this) : pass
@@ -545,6 +546,9 @@ class TDeviceBase(metaclass=ABCMeta) :
     @abstractmethod
     def AdcGetInvalidValue(this) : pass
 
+    @abstractmethod
+    def AdcGetInvalidFloat(this) : pass
+
     #COMM_API int TedAdcGetGroupCount(int dutIdx);
     @abstractmethod
     def AdcGetGroupCount(this, dutIdx) : pass
@@ -593,6 +597,10 @@ class TDeviceBase(metaclass=ABCMeta) :
     @abstractmethod
     def AdcGetVoltage(this, dutIdx, grpIdx, chIdx) : pass
 
+    #TDEVICE_API float TDeviceAdcGetVoltFloat(void* hdl, int dutIdx, int groupIdx, int chIdx)
+    @abstractmethod
+    def AdcGetVoltFloat(this, dutIdx, grpIdx, chIdx) : pass
+
     #COMM_API int TedAdcGetVoltageByPsID(int dutIdx, int psID);
     @abstractmethod
     def AdcGetVoltageByPsID(this, dutIdx, psID) : pass
@@ -605,10 +613,18 @@ class TDeviceBase(metaclass=ABCMeta) :
     @abstractmethod
     def AdcGetAllVoltage(this, dutIdx, grpIdx) : pass
 
+    #TDEVICE_API TED_BOOL TDeviceAdcGetAllVoltFloat(void* hdl, int dutIdx, int groupIdx, float* fvalueArray);
+    @abstractmethod
+    def AdcGetAllVoltFloat(this, dutIdx, grpIdx) : pass
+
     #COMM_API int TedAdcGetCurrent(int dutIdx, int groupIdx, int chIdx);
     @abstractmethod
     def AdcGetCurrent(this, dutIdx, grpIdx, chIdx) : pass
 
+    #TDEVICE_API float TDeviceAdcGetCurrFloat(void* hdl, int dutIdx, int groupIdx, int chIdx)
+    @abstractmethod
+    def AdcGetCurrFloat(this, dutIdx, grpIdx, chIdx) : pass
+
     #COMM_API int TedAdcGetCurrentByPsID(int dutIdx, int psID);
     @abstractmethod
     def AdcGetCurrentByPsID(this, dutIdx, psID) : pass
@@ -621,6 +637,10 @@ class TDeviceBase(metaclass=ABCMeta) :
     @abstractmethod
     def AdcGetAllCurrent(this, dutIdx, grpIdx) : pass
 
+    #TDEVICE_API TED_BOOL TDeviceAdcGetAllCurrFloat(void* hdl, int dutIdx, int groupIdx, float* fvalueArray);
+    @abstractmethod
+    def AdcGetAllCurrFloat(this, dutIdx, grpIdx) : pass
+
     #COMM_API Bool TedAdcSoutSetRBSel(int dutIdx, int value);
     @abstractmethod
     def AdcSoutSetRBSel(this, dutIdx, value) : pass
@@ -629,97 +649,48 @@ class TDeviceBase(metaclass=ABCMeta) :
     @abstractmethod
     def AdcSoutGetRBSel(this, dutIdx) : pass
 
+    #TDEVICE_API TED_BOOL TDeviceAdcGetAllFloat(void* hdl, int dutIdx, int groupIdx, float* fVoltArray, float* fCurrArray)
+    @abstractmethod
+    def AdcGetAllFloat(this, dutIdx, groupIdx) : pass
 
-#
-# class TFileTransfer
-#
-class TFileTransfer :
-
-    class Type(enum.IntEnum) : 
-        T5 = 0
-        
-    class ErrorType(enum.IntEnum) : 
-        Success = 0,
-        SendPacket=1,
-        NoResp=2,
-        FileOpen=3,
-        StorageSize=4,
-        CRC=5
-    
     #TDEVICE_API TFILETRANSFER_HDL TFileTransferCreate(enum TFileTransferType type, TDEVICE_HDL deviceHandle);
-    def __init__(this, type, device) :
-        this.__TFileTransferHandle = TFileTransferCreate(type, device.Handle)
-        this.__FileName = ""
-
-    def __getattr__(this, attrName) :
-        if attrName == 'LastErrorString' : 
-            return this.GetLastErrorString()
-        if attrName == 'FileName' : 
-            return this.__FileName
-        else :
-            raise AttributeError(attrName)
-
-
+    @abstractmethod
+    def TFileTransferCreate(this, type) : pass
+    
     #TDEVICE_API TED_BOOL TFileTransferDestroy(TFILETRANSFER_HDL fileTransferHandle);
-
+    @abstractmethod
+    def TFileTransferDestroy(this, fileTransferHandle) : pass
+    
     #TDEVICE_API TED_BOOL TFileTransferStart(TFILETRANSFER_HDL fileTransferHandle, const char* fileName);
-    def Start(this, fileName) : 
-        this.__FileName = fileName
-        bytesString = fileName.encode('euc-kr')
-        #bytesString = fileName.encode('ascii')
-        #bytesString = fileName.encode('utf-8')
-        ret = TFileTransferStart(this.__TFileTransferHandle, bytesString)
-        return ret
+    @abstractmethod
+    def TFileTransferStart(this, fileTransferHandle, fileName) : pass
 
     #TDEVICE_API TED_BOOL TFileTransferStop(TFILETRANSFER_HDL fileTransferHandle);
-    def Stop(this) : 
-        ret = TFileTransferStop(this.__TFileTransferHandle)
-        return ret
-
+    @abstractmethod
+    def TFileTransferStop(this, fileTransferHandle) : pass
+    
     #TDEVICE_API int TFileTransferGetFileByteSize(TFILETRANSFER_HDL fileTransferHandle);
-    def GetFileByteSize(this) : 
-        ret = TFileTransferGetFileByteSize(this.__TFileTransferHandle)
-        return ret
-
+    @abstractmethod
+    def TFileTransferGetFileByteSize(this, fileTransferHandle) : pass
+        
     #TDEVICE_API int TFileTransferGetTransferByteSize(TFILETRANSFER_HDL fileTransferHandle);
-    def GetTransferByteSize(this) : 
-        ret = TFileTransferGetTransferByteSize(this.__TFileTransferHandle)
-        return ret
+    @abstractmethod
+    def TFileTransferGetTransferByteSize(this, fileTransferHandle) : pass
 
     #TDEVICE_API TED_BOOL TFileTransferIsStart(TFILETRANSFER_HDL fileTransferHandle);
-    def IsStart(this) : 
-        ret = TFileTransferIsStart(this.__TFileTransferHandle)
-        return ret
-
+    @abstractmethod
+    def TFileTransferIsStart(this, fileTransferHandle) : pass
+    
     #TDEVICE_API TED_BOOL TFileTransferIsDone(TFILETRANSFER_HDL fileTransferHandle);
-    def IsDone(this) : 
-        ret = TFileTransferIsDone(this.__TFileTransferHandle)
-        return ret
+    @abstractmethod
+    def TFileTransferIsDone(this, fileTransferHandle) : pass
 
     #TDEVICE_API TED_BOOL TFileTransferIsError(TFILETRANSFER_HDL fileTransferHandle);
-    def IsError(this) : 
-        ret = TFileTransferIsError(this.__TFileTransferHandle)
-        return ret
-
+    @abstractmethod
+    def TFileTransferIsError(this, fileTransferHandle) : pass
+        
     #TDEVICE_API enum TFileTransferError TFileTransferGetLastError(TFILETRANSFER_HDL fileTransferHandle);
-    def GetLastError(this) : 
-        ret = TFileTransferGetLastError(this.__TFileTransferHandle)
-        return ret
+    @abstractmethod
+    def TFileTransferGetLastError(this, fileTransferHandle) : pass
+
 
-    def GetLastErrorString(this) :
-        err = this.GetLastError()
-        if err == TFileTransfer.ErrorType.Success :
-            return "Success"
-        elif err == TFileTransfer.ErrorType.SendPacket :
-            return "SendPacket Error"
-        elif err == TFileTransfer.ErrorType.NoResp :
-            return "NoResp Error"
-        elif err == TFileTransfer.ErrorType.FileOpen :
-            return "FileOpen Error"
-        elif err == TFileTransfer.ErrorType.StorageSize :
-            return "StorageSize Error"
-        elif err == TFileTransfer.ErrorType.CRC :
-            return "CRC Error"
-        else :
-            return "Unknown Error"
-    
