@@ -164,13 +164,15 @@ class TDeviceWin(TDeviceBase) :
 
     def WriteReg(this, regAddr, byteOffset, writeCount, regValueList, writeDataStartIdx=0) :
 
+        dutIdx = 0
+
         if writeDataStartIdx == 0 :
             regValueByteArray=bytes(regValueList)
         else :
             listTmp = regValueList[writeDataStartIdx:(writeDataStartIdx+writeCount)]
             regValueByteArray=bytes(listTmp)
 
-        ret = this.__Api.TDeviceDD_DSIM_MipiWriteReg(this.__DeviceHandle, regAddr, byteOffset, writeCount, regValueByteArray)
+        ret = this.__Api.TDeviceDD_DSIM_MipiWriteReg(this.__DeviceHandle, dutIdx, regAddr, byteOffset, writeCount, regValueByteArray)
         if ret==1 :
             bflag = True
         else :
@@ -178,7 +180,8 @@ class TDeviceWin(TDeviceBase) :
         return bflag
 
     def WriteReg1Byte(this, regAddr, byteOffset, regValue) :
-        ret = this.__Api.TDeviceDD_DSIM_MipiWriteReg1Byte(this.__DeviceHandle, regAddr, byteOffset, c_char(regValue))
+        dutIdx = 0
+        ret = this.__Api.TDeviceDD_DSIM_MipiWriteReg1Byte(this.__DeviceHandle, dutIdx, regAddr, byteOffset, c_char(regValue))
         if ret==1 :
             bflag = True
         else :
